Module logging — Inmanta 2017.2.1 documentation

# Module logging

> - License: Apache 2.0
> - Version: 0.4.1
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/logging.git

## Entities

entity `logging::LogDir`

  Parents: `std::Entity`

  Models a log file in the configuration model

  attribute string `tag`=''
  attribute string `priority`
  attribute string `matches`='.*\.log'
  attribute string `name`
  attribute string `type`=''
  attribute string `path`
  relation std::Host `host` [1]

    other end: `std::Host.log_dirs [0:*]`

  The following implements statements select implementations for this entity:

  > - `std::none`

entity `logging::LogFile`

  Parents: `std::Entity`

  Models a log file in the configuration model

  attribute string `tag`=''
  attribute string `type`=''
  attribute string `path`
  relation std::Host `host` [1]

    other end: `std::Host.log_files [0:*]`

  The following implements statements select implementations for this entity:

  > - `std::none`